package Crypt::OpenSSL3::PEM;
$Crypt::OpenSSL3::PEM::VERSION = '0.012';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: PEM handling functions

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::PEM - PEM handling functions

=head1 VERSION

version 0.012

=head1 FUNCTIONS

=head2 read

=head2 write

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2025 by Leon Timmermans.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
