package Crypt::OpenSSL3::ASN1::Object;
$Crypt::OpenSSL3::ASN1::Object::VERSION = '0.012';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: An ASN Object Identifier

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::ASN1::Object - An ASN Object Identifier

=head1 VERSION

version 0.012

=head1 METHODS

=head2 cmp

=head2 decode_der

=head2 encode_der

=head2 from_nid

=head2 from_text

=head2 get_data

=head2 length

=head2 to_nid

=head2 to_text

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2025 by Leon Timmermans.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
