package Crypt::OpenSSL3::X509::Algorithm;
$Crypt::OpenSSL3::X509::Algorithm::VERSION = '0.012';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

#ABSTRACT: A X509 algorithm identifier

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::X509::Algorithm - A X509 algorithm identifier

=head1 VERSION

version 0.012

=head1 METHODS

=head2 new

=head2 decode_der

=head2 encode_der

=head2 dup

=head2 cmp

=head2 copy

=head2 get

=head2 set

=head2 set_md

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2025 by Leon Timmermans.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
