package Crypt::OpenSSL3::X509::BasicConstraints;
$Crypt::OpenSSL3::X509::BasicConstraints::VERSION = '0.012';
use strict;
use warnings;

1;

#ABSTRACT: An X509 BasicConstraints extension

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::X509::BasicConstraints - An X509 BasicConstraints extension

=head1 VERSION

version 0.012

=head1 METHODS

=head2 new

=head2 get_ca

=head2 get_pathlen

=head2 set_ca

=head2 set_pathlen

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2025 by Leon Timmermans.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
